# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13vssref_common.proto\x12\x06VSSRef\"D\n\x05Robot\x12\x10\n\x08robot_id\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x13\n\x0borientation\x18\x04 \x01(\x01\"H\n\x05\x46rame\x12 \n\tteamColor\x18\x01 \x01(\x0e\x32\r.VSSRef.Color\x12\x1d\n\x06robots\x18\x02 \x03(\x0b\x32\r.VSSRef.Robot*s\n\x04\x46oul\x12\r\n\tFREE_KICK\x10\x00\x12\x10\n\x0cPENALTY_KICK\x10\x01\x12\r\n\tGOAL_KICK\x10\x02\x12\r\n\tFREE_BALL\x10\x03\x12\x0b\n\x07KICKOFF\x10\x04\x12\x08\n\x04STOP\x10\x05\x12\x0b\n\x07GAME_ON\x10\x06\x12\x08\n\x04HALT\x10\x07*\'\n\x05\x43olor\x12\x08\n\x04\x42LUE\x10\x00\x12\n\n\x06YELLOW\x10\x01\x12\x08\n\x04NONE\x10\x02*[\n\x08Quadrant\x12\x0f\n\x0bNO_QUADRANT\x10\x00\x12\x0e\n\nQUADRANT_1\x10\x01\x12\x0e\n\nQUADRANT_2\x10\x02\x12\x0e\n\nQUADRANT_3\x10\x03\x12\x0e\n\nQUADRANT_4\x10\x04*~\n\x04Half\x12\x0b\n\x07NO_HALF\x10\x00\x12\x0e\n\nFIRST_HALF\x10\x01\x12\x0f\n\x0bSECOND_HALF\x10\x02\x12\x17\n\x13OVERTIME_FIRST_HALF\x10\x03\x12\x18\n\x14OVERTIME_SECOND_HALF\x10\x04\x12\x15\n\x11PENALTY_SHOOTOUTS\x10\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOUL._serialized_start=175
  _FOUL._serialized_end=290
  _COLOR._serialized_start=292
  _COLOR._serialized_end=331
  _QUADRANT._serialized_start=333
  _QUADRANT._serialized_end=424
  _HALF._serialized_start=426
  _HALF._serialized_end=552
  _ROBOT._serialized_start=31
  _ROBOT._serialized_end=99
  _FRAME._serialized_start=101
  _FRAME._serialized_end=173
# @@protoc_insertion_point(module_scope)
