from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Command(_message.Message):
    __slots__ = ["id", "wheel_left", "wheel_right", "yellowteam"]
    ID_FIELD_NUMBER: _ClassVar[int]
    WHEEL_LEFT_FIELD_NUMBER: _ClassVar[int]
    WHEEL_RIGHT_FIELD_NUMBER: _ClassVar[int]
    YELLOWTEAM_FIELD_NUMBER: _ClassVar[int]
    id: int
    wheel_left: float
    wheel_right: float
    yellowteam: bool
    def __init__(self, id: _Optional[int] = ..., yellowteam: bool = ..., wheel_left: _Optional[float] = ..., wheel_right: _Optional[float] = ...) -> None: ...

class Commands(_message.Message):
    __slots__ = ["robot_commands"]
    ROBOT_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    robot_commands: _containers.RepeatedCompositeFieldContainer[Command]
    def __init__(self, robot_commands: _Optional[_Iterable[_Union[Command, _Mapping]]] = ...) -> None: ...
