# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_placement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import vssref_common_pb2 as vssref__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16vssref_placement.proto\x12\x12VSSRef.team_to_ref\x1a\x13vssref_common.proto\"0\n\x10VSSRef_Placement\x12\x1c\n\x05world\x18\x01 \x01(\x0b\x32\r.VSSRef.Frameb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_placement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VSSREF_PLACEMENT._serialized_start=67
  _VSSREF_PLACEMENT._serialized_end=115
# @@protoc_insertion_point(module_scope)
