import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BallReplacement(_message.Message):
    __slots__ = ["vx", "vy", "x", "y"]
    VX_FIELD_NUMBER: _ClassVar[int]
    VY_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    vx: float
    vy: float
    x: float
    y: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., vx: _Optional[float] = ..., vy: _Optional[float] = ...) -> None: ...

class Replacement(_message.Message):
    __slots__ = ["ball", "robots"]
    BALL_FIELD_NUMBER: _ClassVar[int]
    ROBOTS_FIELD_NUMBER: _ClassVar[int]
    ball: BallReplacement
    robots: _containers.RepeatedCompositeFieldContainer[RobotReplacement]
    def __init__(self, ball: _Optional[_Union[BallReplacement, _Mapping]] = ..., robots: _Optional[_Iterable[_Union[RobotReplacement, _Mapping]]] = ...) -> None: ...

class RobotReplacement(_message.Message):
    __slots__ = ["position", "turnon", "yellowteam"]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    TURNON_FIELD_NUMBER: _ClassVar[int]
    YELLOWTEAM_FIELD_NUMBER: _ClassVar[int]
    position: _common_pb2.Robot
    turnon: bool
    yellowteam: bool
    def __init__(self, position: _Optional[_Union[_common_pb2.Robot, _Mapping]] = ..., yellowteam: bool = ..., turnon: bool = ...) -> None: ...
