from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

BLUE: Color
DESCRIPTOR: _descriptor.FileDescriptor
FIRST_HALF: Half
FREE_BALL: Foul
FREE_KICK: Foul
GAME_ON: Foul
GOAL_KICK: Foul
HALT: Foul
KICKOFF: Foul
NONE: Color
NO_HALF: Half
NO_QUADRANT: Quadrant
OVERTIME_FIRST_HALF: Half
OVERTIME_SECOND_HALF: Half
PENALTY_KICK: Foul
PENALTY_SHOOTOUTS: Half
QUADRANT_1: Quadrant
QUADRANT_2: Quadrant
QUADRANT_3: Quadrant
QUADRANT_4: Quadrant
SECOND_HALF: Half
STOP: Foul
YELLOW: Color

class Frame(_message.Message):
    __slots__ = ["robots", "teamColor"]
    ROBOTS_FIELD_NUMBER: _ClassVar[int]
    TEAMCOLOR_FIELD_NUMBER: _ClassVar[int]
    robots: _containers.RepeatedCompositeFieldContainer[Robot]
    teamColor: Color
    def __init__(self, teamColor: _Optional[_Union[Color, str]] = ..., robots: _Optional[_Iterable[_Union[Robot, _Mapping]]] = ...) -> None: ...

class Robot(_message.Message):
    __slots__ = ["orientation", "robot_id", "x", "y"]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ROBOT_ID_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    orientation: float
    robot_id: int
    x: float
    y: float
    def __init__(self, robot_id: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., orientation: _Optional[float] = ...) -> None: ...

class Foul(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Color(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Quadrant(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Half(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
