import vssref_common_pb2 as _vssref_common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VSSRef_Placement(_message.Message):
    __slots__ = ["world"]
    WORLD_FIELD_NUMBER: _ClassVar[int]
    world: _vssref_common_pb2.Frame
    def __init__(self, world: _Optional[_Union[_vssref_common_pb2.Frame, _Mapping]] = ...) -> None: ...
