# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcommand.proto\x12\x17\x66ira_message.sim_to_ref\"R\n\x07\x43ommand\x12\n\n\x02id\x18\x01 \x01(\r\x12\x12\n\nyellowteam\x18\x02 \x01(\x08\x12\x12\n\nwheel_left\x18\x06 \x01(\x01\x12\x13\n\x0bwheel_right\x18\x07 \x01(\x01\"D\n\x08\x43ommands\x12\x38\n\x0erobot_commands\x18\x01 \x03(\x0b\x32 .fira_message.sim_to_ref.Commandb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMAND._serialized_start=42
  _COMMAND._serialized_end=124
  _COMMANDS._serialized_start=126
  _COMMANDS._serialized_end=194
# @@protoc_insertion_point(module_scope)
