# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vssref_command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import vssref_common_pb2 as vssref__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vssref_command.proto\x12\x12VSSRef.ref_to_team\x1a\x13vssref_common.proto\"\xa9\x01\n\x0eVSSRef_Command\x12\x1a\n\x04\x66oul\x18\x01 \x01(\x0e\x32\x0c.VSSRef.Foul\x12 \n\tteamcolor\x18\x02 \x01(\x0e\x32\r.VSSRef.Color\x12&\n\x0c\x66oulQuadrant\x18\x03 \x01(\x0e\x32\x10.VSSRef.Quadrant\x12\x11\n\ttimestamp\x18\x04 \x01(\x01\x12\x1e\n\x08gameHalf\x18\x05 \x01(\x0e\x32\x0c.VSSRef.Halfb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vssref_command_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VSSREF_COMMAND._serialized_start=66
  _VSSREF_COMMAND._serialized_end=235
# @@protoc_insertion_point(module_scope)
