# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: packet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import command_pb2 as command__pb2
import replacement_pb2 as replacement__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpacket.proto\x12\x17\x66ira_message.sim_to_ref\x1a\rcommand.proto\x1a\x11replacement.proto\x1a\x0c\x63ommon.proto\"o\n\x06Packet\x12.\n\x03\x63md\x18\x01 \x01(\x0b\x32!.fira_message.sim_to_ref.Commands\x12\x35\n\x07replace\x18\x02 \x01(\x0b\x32$.fira_message.sim_to_ref.Replacement\"\x8d\x01\n\x0b\x45nvironment\x12\x0c\n\x04step\x18\x01 \x01(\r\x12\"\n\x05\x66rame\x18\x02 \x01(\x0b\x32\x13.fira_message.Frame\x12\"\n\x05\x66ield\x18\x03 \x01(\x0b\x32\x13.fira_message.Field\x12\x12\n\ngoals_blue\x18\x04 \x01(\r\x12\x14\n\x0cgoals_yellow\x18\x05 \x01(\r2_\n\x08Simulate\x12S\n\x08Simulate\x12\x1f.fira_message.sim_to_ref.Packet\x1a$.fira_message.sim_to_ref.Environment\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'packet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PACKET._serialized_start=89
  _PACKET._serialized_end=200
  _ENVIRONMENT._serialized_start=203
  _ENVIRONMENT._serialized_end=344
  _SIMULATE._serialized_start=346
  _SIMULATE._serialized_end=441
# @@protoc_insertion_point(module_scope)
