# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: replacement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11replacement.proto\x12\x17\x66ira_message.sim_to_ref\x1a\x0c\x63ommon.proto\"]\n\x10RobotReplacement\x12%\n\x08position\x18\x01 \x01(\x0b\x32\x13.fira_message.Robot\x12\x12\n\nyellowteam\x18\x05 \x01(\x08\x12\x0e\n\x06turnon\x18\x06 \x01(\x08\"?\n\x0f\x42\x61llReplacement\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\n\n\x02vx\x18\x03 \x01(\x01\x12\n\n\x02vy\x18\x04 \x01(\x01\"\x80\x01\n\x0bReplacement\x12\x36\n\x04\x62\x61ll\x18\x01 \x01(\x0b\x32(.fira_message.sim_to_ref.BallReplacement\x12\x39\n\x06robots\x18\x02 \x03(\x0b\x32).fira_message.sim_to_ref.RobotReplacementb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'replacement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROBOTREPLACEMENT._serialized_start=60
  _ROBOTREPLACEMENT._serialized_end=153
  _BALLREPLACEMENT._serialized_start=155
  _BALLREPLACEMENT._serialized_end=218
  _REPLACEMENT._serialized_start=221
  _REPLACEMENT._serialized_end=349
# @@protoc_insertion_point(module_scope)
