import vssref_common_pb2 as _vssref_common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VSSRef_Command(_message.Message):
    __slots__ = ["foul", "foulQuadrant", "gameHalf", "teamcolor", "timestamp"]
    FOULQUADRANT_FIELD_NUMBER: _ClassVar[int]
    FOUL_FIELD_NUMBER: _ClassVar[int]
    GAMEHALF_FIELD_NUMBER: _ClassVar[int]
    TEAMCOLOR_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    foul: _vssref_common_pb2.Foul
    foulQuadrant: _vssref_common_pb2.Quadrant
    gameHalf: _vssref_common_pb2.Half
    teamcolor: _vssref_common_pb2.Color
    timestamp: float
    def __init__(self, foul: _Optional[_Union[_vssref_common_pb2.Foul, str]] = ..., teamcolor: _Optional[_Union[_vssref_common_pb2.Color, str]] = ..., foulQuadrant: _Optional[_Union[_vssref_common_pb2.Quadrant, str]] = ..., timestamp: _Optional[float] = ..., gameHalf: _Optional[_Union[_vssref_common_pb2.Half, str]] = ...) -> None: ...
